@@ -1,8 +1,26 @@
 #Copyright ReportLab Europe Ltd. 2000-2017
 #see license.txt for license details
 #history https://bitbucket.org/rptlab/reportlab/history-node/tip/src/reportlab/platypus/doctemplate.py
-
-__version__='3.4.2'
+__all__ = (
+        'ActionFlowable',
+        'BaseDocTemplate',
+        'CurrentFrameFlowable',
+        'FrameActionFlowable',
+        'FrameBreak',
+        'Indenter',
+        'IndexingFlowable',
+        'LayoutError',
+        'LCActionFlowable',
+        'NextFrameFlowable',
+        'NextPageTemplate',
+        'NotAtTopPageBreak',
+        'NullActionFlowable',
+        'PageAccumulator',
+        'PageBegin',
+        'PageTemplate',
+        'SimpleDocTemplate',
+        )
+__version__='3.5.20'
 
 __doc__="""
 This module contains the core structure of platypus.
@@ -468,6 +486,7 @@ class BaseDocTemplate:
                     'author':None,
                     'subject':None,
                     'creator':None,
+                    'producer':None,
                     'keywords':[],
                     'invariant':None,
                     'pageCompression':None,
@@ -659,8 +678,9 @@ class BaseDocTemplate:
         '''What to do at the beginning of a frame'''
         f = self.frame
         if f._atTop:
-            if self.showBoundary or self.frame.showBoundary:
-                self.frame.drawBoundary(self.canv)
+            boundary = self.frame.showBoundary or self.showBoundary
+            if boundary:
+                self.frame.drawBoundary(self.canv,boundary)
         f._leftExtraIndent = self._leftExtraIndent
         f._rightExtraIndent = self._rightExtraIndent
         f._frameBGs = self._frameBGs
@@ -912,7 +932,7 @@ class BaseDocTemplate:
                         flowables[0:0] = S[1:]  # put rest of splitted flowables back on the list
                         _addGeneratedContent(flowables,frame)
                     else:
-                        flowables[0:0] = S  # put splitted flowables back on the list
+                        flowables[0:0] = S  # put split flowables back on the list
                 else:
                     if hasattr(f,'_postponed'):
                         ident = "Flowable %s%s too large on page %d in frame %r%s of template %r" % \
@@ -970,6 +990,7 @@ class BaseDocTemplate:
         canv.setTitle(self.title)
         canv.setSubject(self.subject)
         canv.setCreator(self.creator)
+        canv.setProducer(self.producer)
         canv.setKeywords(self.keywords)
         if self.displayDocTitle is not None:
             canv.setViewerPreference('DisplayDocTitle',['false','true'][self.displayDocTitle])
